pub struct SagaManager<A, AR, Publisher, Saga, Error>
where Publisher: ActionPublisher<A, Error>, Saga: ActionComputation<AR, A>,
{ /* private fields */ }
Saga Manager.

It is using a [Saga] to react to the action result and to publish the new actions. It is using an ActionPublisher to publish the new actions.

Generic parameters:

  • A - Action / Command
  • AR - Action Result / Event
  • Publisher - Action Publisher
  • Error - Error

Implementations

source

impl<A, AR, Publisher, Saga, Error> SagaManager<A, AR, Publisher, Saga, Error>
where Publisher: ActionPublisher<A, Error>, Saga: ActionComputation<AR, A>,

source

pub fn new(action_publisher: Publisher, saga: Saga) -> Self

Creates a new instance of SagaManager.

source

pub async fn handle(&self, action_result: &AR) -> Result<Vec<A>, Error>

Handles the action result by publishing it to the external system.