pub trait EventComputation<C, S, E, Error = ()> {
// Required method
fn compute_new_events(
&self,
current_events: &[E],
command: &C,
) -> Result<Vec<E>, Error>;
}Expand description
Formalizes the Event Computation algorithm / event sourced system for the decider to handle commands based on the current events, and produce new events.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".